Struct aptos_types::epoch_state::EpochState
source · [−]pub struct EpochState {
pub epoch: u64,
pub verifier: ValidatorVerifier,
}Expand description
EpochState represents a trusted validator set to validate messages from the specific epoch, it could be updated with EpochChangeProof.
Fields
epoch: u64verifier: ValidatorVerifierImplementations
sourceimpl EpochState
impl EpochState