Module aptos_types::event
source · [−]Structs
A Rust representation of an Event Handle Resource.
A struct that represents a globally unique id for an Event stream that a user can listen to. By design, the lower part of EventKey is the same as account address.