pub struct LedgerInfoWithPartialSignatures { /* private fields */ }Expand description
Contains the ledger info and partially aggregated signature from a set of validators, this data is only used during the aggregating the votes from different validators and is not persisted in DB.
Implementations
sourceimpl LedgerInfoWithPartialSignatures
impl LedgerInfoWithPartialSignatures
pub fn new(ledger_info: LedgerInfo, signatures: PartialSignatures) -> Self
pub fn commit_info(&self) -> &BlockInfo
pub fn remove_signature(&mut self, validator: AccountAddress)
pub fn add_signature(&mut self, validator: AccountAddress, signature: Signature)
pub fn signatures(&self) -> &HashMap<AccountAddress, Signature>
pub fn aggregate_signatures(
&self,
verifier: &ValidatorVerifier
) -> Result<LedgerInfoWithSignatures, VerifyError>
pub fn ledger_info(&self) -> &LedgerInfo
pub fn partial_sigs(&self) -> &PartialSignatures