pub enum OnChainConsensusConfig {
    V1(ConsensusConfigV1),
}
The on-chain consensus config, in order to be able to add fields, we use enum to wrap the actual struct.

Variants

V1(ConsensusConfigV1)

Implementations

The public interface that exposes all values with safe fallback.

The number of recent rounds that don’t count into reputations.

Decouple execution from consensus or not.

Backpressure controls

  1. how much gaps can be between ordered and committed blocks in decoupled execution setup.
  2. how much gaps can be between the root and the remote sync info ledger.