Struct aptos_types::proof::definition::AccumulatorRangeProof
source · [−]pub struct AccumulatorRangeProof<H> { /* private fields */ }Expand description
A proof that is similar to AccumulatorProof, but can be used to authenticate a range of
leaves. For example, given the following accumulator:
root
/ \
/ \
/ \
o o
/ \ / \
/ \ / \
X o o Y
/ \ / \ / \ / \
o o a b c Z o oif the proof wants to show that [a, b, c] exists in the accumulator, it would need X on the
left and Y and Z on the right.
Implementations
sourceimpl<H> AccumulatorRangeProof<H> where
H: CryptoHasher,
impl<H> AccumulatorRangeProof<H> where
H: CryptoHasher,
sourcepub fn new(left_siblings: Vec<HashValue>, right_siblings: Vec<HashValue>) -> Self
pub fn new(left_siblings: Vec<HashValue>, right_siblings: Vec<HashValue>) -> Self
Constructs a new AccumulatorRangeProof using left_siblings and right_siblings.
sourcepub fn left_siblings(&self) -> &Vec<HashValue>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
pub fn left_siblings(&self) -> &Vec<HashValue>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
Get all the left siblngs.