Struct aptos_types::proof::definition::TransactionAccumulatorSummary
source · [−]pub struct TransactionAccumulatorSummary(pub InMemoryAccumulator<TransactionAccumulatorHasher>);Expand description
An in-memory accumulator for storing a summary of the core transaction info accumulator. It is a summary in the sense that it only stores maximally frozen subtree nodes rather than storing all leaves and internal nodes.
Light clients and light nodes use this type to store their currently verified
view of the transaction accumulator. When verifying state proofs, these clients
attempt to extend their accumulator summary with an AccumulatorConsistencyProof
to verifiably ratchet their trusted view of the accumulator to a newer state.
Tuple Fields
0: InMemoryAccumulator<TransactionAccumulatorHasher>Implementations
sourceimpl TransactionAccumulatorSummary
impl TransactionAccumulatorSummary
pub fn new(
accumulator: InMemoryAccumulator<TransactionAccumulatorHasher>
) -> Result<Self>
pub fn version(&self) -> Version
pub fn root_hash(&self) -> HashValue
sourcepub fn verify_consistency(&self, ledger_info: &LedgerInfo) -> Result<()>
pub fn verify_consistency(&self, ledger_info: &LedgerInfo) -> Result<()>
Verify that this accumulator summary is “consistent” with the given
LedgerInfo, i.e., they both have the same version and accumulator
root hash.
sourcepub fn try_from_genesis_proof(
genesis_proof: AccumulatorConsistencyProof,
target_version: Version
) -> Result<Self>
pub fn try_from_genesis_proof(
genesis_proof: AccumulatorConsistencyProof,
target_version: Version
) -> Result<Self>
Try to build an accumulator summary using a consistency proof starting from pre-genesis.
sourcepub fn try_extend_with_proof(
&self,
consistency_proof: &AccumulatorConsistencyProof,
target_li: &LedgerInfo
) -> Result<Self>
pub fn try_extend_with_proof(
&self,
consistency_proof: &AccumulatorConsistencyProof,
target_li: &LedgerInfo
) -> Result<Self>
Try to extend an existing accumulator summary with a consistency proof
starting from our current version. Then validate that the resulting
accumulator summary is consistent with the given target LedgerInfo.