pub enum OnChainConsensusConfig {
V1(ConsensusConfigV1),
}Expand description
The on-chain consensus config, in order to be able to add fields, we use enum to wrap the actual struct.
Variants
V1(ConsensusConfigV1)
Implementations
sourceimpl OnChainConsensusConfig
impl OnChainConsensusConfig
The public interface that exposes all values with safe fallback.
sourcepub fn leader_reputation_exclude_round(&self) -> u64
pub fn leader_reputation_exclude_round(&self) -> u64
The number of recent rounds that don’t count into reputations.
sourcepub fn decoupled_execution(&self) -> bool
pub fn decoupled_execution(&self) -> bool
Decouple execution from consensus or not.
sourcepub fn back_pressure_limit(&self) -> u64
pub fn back_pressure_limit(&self) -> u64
Backpressure controls
- how much gaps can be between ordered and committed blocks in decoupled execution setup.
- how much gaps can be between the root and the remote sync info ledger.
pub fn proposer_election_type(&self) -> &ProposerElectionType